Index: asterisk/apps/app_read.c
===================================================================
RCS file: /usr/cvsroot/asterisk/apps/app_read.c,v
retrieving revision 1.26
diff -u -r1.26 app_read.c
--- asterisk/apps/app_read.c	26 Oct 2005 19:48:14 -0000	1.26
+++ asterisk/apps/app_read.c	2 Nov 2005 07:08:00 -0000
@@ -39,6 +39,7 @@
 #include "asterisk/translate.h"
 #include "asterisk/options.h"
 #include "asterisk/utils.h"
+#include "asterisk/indications.h"
 
 static char *tdesc = "Read Variable Application";
 
@@ -51,6 +52,7 @@
 "Reads a #-terminated string of digits a certain number of times from the\n"
 "user in to the given variable.\n"
 "  filename   -- file to play before reading digits.\n"
+"                If filename starts with 'tone-' it is interpreted as tone name to play.\n"
 "  maxdigits  -- maximum acceptable number of digits. Stops reading after\n"
 "                maxdigits have been entered (without requiring the user to\n"
 "                press the '#' key).\n"
@@ -88,6 +90,7 @@
 	int x = 0;
 	char *argcopy = NULL;
 	char *args[8];
+	struct tone_zone_sound *ts;
 
 	if (ast_strlen_zero(data)) {
 		ast_log(LOG_WARNING, "Read requires an argument (variable)\n");
@@ -172,7 +175,31 @@
 	if (!res) {
 		while(tries && !res) {
 			ast_stopstream(chan);
-			res = ast_app_getdata(chan, filename, tmp, maxdigits, to);
+			ts = NULL;
+			if(filename && !strncasecmp(filename,"tone-",5)) {
+				ast_log(LOG_DEBUG,"Using tone: %s\n",filename+5);
+    				ts = ast_get_indication_tone(chan->zone,filename+5);
+			}
+	    		if (ts && ts->data[0]) {
+				if(!to)
+					to = chan->pbx ? chan->pbx->rtimeout * 1000 : 6000;
+		                res = ast_playtones_start(chan, 0, ts->data, 0);
+    				for (x = 0; x < maxdigits; ) {
+            				res = ast_waitfordigit(chan, to);
+                    			ast_playtones_stop(chan);
+            				if (res < 1) {
+						tmp[x]='\0';
+                    				break;
+					}
+            				tmp[x++] = res;
+                    			if (tmp[x-1] == '#') {
+                            			tmp[x-1] = '\0';
+						break;
+                    			}
+    				}
+			} else {
+				res = ast_app_getdata(chan, filename, tmp, maxdigits, to);
+			}
 			if (res > -1) {
 				pbx_builtin_setvar_helper(chan, varname, tmp);
 				if (!ast_strlen_zero(tmp)) {
